
## MetaCat

Data Catalog designed for use with the [Rucio](https://rucio.cern.ch/) data management system

* [Documentation](docs/index.md)

### Related Projects

* [Data Dispatcher](https://github.com/fermitools/data_dispatcher) 
* [Declad](https://github.com/fermitools/declad)
